CRAN imposes an impressive list of tests on every package before publication.
This suite of test is available in every R installation.
Hence we use this full suite of tests too.
Notice that check_package() runs several additional tests.
Arguments
- x
Either a
checklistobject or a path to the source code. Defaults to..- quiet
Whether to print check output during checking.
- time_out
The time in seconds to wait for a response from the world clock API. Default is 15 seconds, but you can increase this if you have a slow internet connection. If the world clock API is not available, the system clock will be used without a warning, but the check will be less reliable.
See also
Other package:
check_description(),
check_documentation(),
check_environment(),
check_license(),
check_package(),
tidy_desc()