A convenience function that runs all packages related tests in sequence.
The details section lists the relevant functions.
After fixing a problem, you can quickly check if it is solved by running only
the related check.
But we still recommend to run check_package() before you push to GitHub.
And only push when the functions indicate that there are no problems.
This catches most problems before sending the code to GitHub.
Usage
check_package(
x = ".",
fail = !interactive(),
pkgdown = interactive(),
quiet = FALSE,
time_out = 30
)Arguments
- x
Either a
checklistobject or a path to the source code. Defaults to..- fail
Should the function return an error in case of a problem? Defaults to
TRUEon a non-interactive session andFALSEon an interactive session.- pkgdown
Test pkgdown website. Defaults to
TRUEon an interactive session andFALSEon a non-interactive session.- quiet
Whether to print check output during checking.
- time_out
The time in seconds to wait for a response from the world clock API. Default is 15 seconds, but you can increase this if you have a slow internet connection. If the world clock API is not available, the system clock will be used without a warning, but the check will be less reliable.
See also
Other package:
check_cran(),
check_description(),
check_documentation(),
check_environment(),
check_license(),
tidy_desc()